import com.smartvault.proto.NodeProto;

import java.awt.*;
import java.net.URI;
import java.nio.file.Paths;
import java.util.Scanner;

public class Program
{

    private static Scanner keyboard = new Scanner(System.in);

    public static void main(String[] args)
    {
        try
        {
            SmartVault smartVault = new SmartVault();
            authenticate(smartVault);

            //Upload file
            System.out.println("\nLet's upload a file to \"My first folder\".");
            String localFile = getLocalFile();
            String remoteFolder = getRemoteFolder(smartVault, "My First folder");
            smartVault.uploadFile(localFile, remoteFolder);
            System.out.println("Upload complete.");
            System.out.println("Press any key to continue..");
            System.in.read();

            //Create folder
            System.out.println("\nLet's create a folder");
            String remoteFolder1 = getRemoteFolder(smartVault);
            System.out.println("What do you want to call the folder?");
            String folder_1 = keyboard.nextLine();
            smartVault.createFolder(remoteFolder1, folder_1);
            System.out.println(String.format("%s has been created.", folder_1));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Move file to folder_1
            System.out.println(String.format("Let's move the file into %s.", folder_1));
            String remoteFile = getRemoteFile(remoteFolder, Paths.get(localFile).getFileName().toString());
            remoteFolder1 = getRemoteFolder(smartVault, folder_1);
            String newRemoteFile = getRemoteFile(remoteFolder1, Paths.get(localFile).getFileName().toString());
            smartVault.moveFile(remoteFile, newRemoteFile);
            System.out.println(String.format("%s has been moved to %s", Paths.get(remoteFile).getFileName().toString(), folder_1));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Make a copy of folder_1 (folder_2)
            System.out.println(String.format("Let's make a copy of %s", folder_1));
            System.out.println("What would you like to name the copy?");
            String folder_2 = keyboard.nextLine();
            String remoteFolder2 = getRemoteFolder(smartVault, folder_2);
            smartVault.copy(remoteFolder1, remoteFolder2);
            System.out.println(String.format("%s has been copied", folder_1));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Move folder_2 inside folder_1
            System.out.println(String.format("Let's move %s inside %s", folder_2, folder_1));
            smartVault.moveFolder(remoteFolder2, remoteFolder1);
            System.out.println(String.format("%s has been moved inside %s", folder_2, folder_1));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Modify folder_1 properties
            System.out.println(String.format("Let's modify the description of %s", folder_1));
            System.out.println("What would you like to change the description of the folder to?");
            String folderDescription = keyboard.nextLine();
            smartVault.modifyFolder(remoteFolder1, folderDescription);
            System.out.println(String.format("The description of %s has been updated", folder_1));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Modify file properties
            System.out.println(String.format("Let's modify the description of %s", Paths.get(localFile).getFileName().toString()));
            System.out.println("What would you like to change the description of the file to?");
            String fileDescription = keyboard.nextLine();
            smartVault.modifyFile(newRemoteFile, fileDescription);
            System.out.println(String.format("The description of %s has been updated", Paths.get(newRemoteFile).getFileName().toString()));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Delete file
            System.out.println(String.format("Let's delete %s", Paths.get(newRemoteFile).getFileName().toString()));
            smartVault.deleteFile(newRemoteFile);
            System.out.println(String.format("%s has been deleted", folder_1));
            System.out.println("Press any key to continue..");
            System.in.read();

            //Delete folder
            System.out.println(String.format("Let's make a copy of %s", Paths.get(newRemoteFile).getFileName().toString()));
            smartVault.deleteFolder(remoteFolder1);
            System.out.println(String.format("%s has been deleted", folder_1));

        }
        catch (Exception e)
        {
            e.printStackTrace();
        }

        System.out.println("\nPress 'Enter' key to exit");
        keyboard.nextLine();
    }

    private static void authenticate(SmartVault smartVault) throws Exception
    {
        // Autonomous authentication
        System.out.print("Enter your email address: ");
        String email = keyboard.nextLine();

        System.out.print("Have you authorized this application? [y/n]: ");
        String response = keyboard.nextLine();

        if (!response.toLowerCase().startsWith("y"))
        {
            String url = smartVault.requestAuthorization(email);
            Desktop.getDesktop().browse(URI.create(url));
            System.out.println("\nPress 'Enter' once you have allowed this application.");
            keyboard.nextLine();
        }

        smartVault.authenticate(email);
    }

    private static String getLocalFile()
    {
        System.out.println("Enter the path to a file to upload. " +
                "(Hint: drag a file to the console window): ");
        String localFile = keyboard.nextLine();

        return localFile.replace("\"", ""); // Remove quotes, if supplied
    }

    private static String getRemoteFile(String remoteFolder, String fileName)
    {
        return String.format("%s/%s",
                remoteFolder, fileName);
    }

    private static String getRemoteFolder(SmartVault smartVault, String folderName) throws Exception
    {
        NodeProto.NodeResponse rootNode = smartVault.browsePath("nodes/pth");
        String account = rootNode.getMessage().getChildrenList().get(0).getName();

        return String.format("/nodes/pth/%s/My First Vault/%s", account, folderName);
    }

    private static String getRemoteFolder(SmartVault smartVault) throws Exception
    {
        NodeProto.NodeResponse rootNode = smartVault.browsePath("nodes/pth");
        String account = rootNode.getMessage().getChildrenList().get(0).getName();

        return String.format("/nodes/pth/%s/My First Vault", account);
    }
}