/*****************************************************************************
Copyright (c) 2011 SmartVault, Inc.

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
 ******************************************************************************/
package com.smartvault.rest;

/**
 * The base class of all of the configuration classes. These classes are used to provide 
 * information to the various client interfaces.
 *                        
 */
public class ServerCfgBase {
	private static final String HTTPS_REST_SMARTVAULT_COM = "https://rest.smartvault.com"; //$NON-NLS-1$
	private String rootUri;

	/**
	 * Default Constructor
	 * 
	 * Uses production facility for REST API.
	 */
	public ServerCfgBase() {
		this.rootUri = HTTPS_REST_SMARTVAULT_COM;
	}

	/**
	 * Copy Constructor
	 * @param cfg the configuration to copy.
	 */
	protected ServerCfgBase(ServerCfgBase cfg) {
		this.rootUri = cfg.rootUri;
	}

	/**
	 * Constructor
	 *
	 * Use this constructor to override the root uri. This is useful for connecting
	 * to the testing facility.
	 * 
	 * @param rootUri the root URI to use for the REST API.  
	 * 
	 */
	protected ServerCfgBase(String rootUri) {
		this.rootUri = rootUri;
	}

	/**
	 * @return the root uri
	 */
	public String getRootUri() {
		return this.rootUri;
	}
}